@@ -1,6 +1,6 @@
 def get_count(queryset):
     """Determine an object count in optimized manner. Incompatible with custom values/distinct/group by"""
     try:
-        return queryset.values('id').order_by().count()
+        return queryset.values('pk').order_by().count()
     except (AttributeError, TypeError):
         return len(queryset)
