@@ -1,3 +1,5 @@
+from typing import List
+
 from django.db import models
 
 from rest_framework import serializers
@@ -16,14 +18,14 @@ class SerializerRequestMixin:
 
 
 class SelectObjectsSerializer(serializers.Serializer):
-    ids = serializers.ListField(
-        child=serializers.IntegerField(min_value=0),
-        min_length=1,
-    )
+    ids = serializers.ListField(child=serializers.IntegerField(min_value=0))
+
+    @property
+    def selected_ids(self) -> List[int]:
+        return self.validated_data.get('ids', [])
 
     @property
     def selected_objects(self) -> models.QuerySet:
         objects = self.context['view'].get_queryset()
-        ids = self.validated_data.get('ids', [])
-        objects = objects.filter(id__in=ids)
+        objects = objects.filter(id__in=self.selected_ids)
         return objects
